@echo off
rem ======================================================================
::
::	RUN IF OLDER
::	Execute a task only if it is older [n] days
::	uses SHOWDATE to generate timestamps
::
::  http://www.axel-hahn.de/axel/page_compi/bat_runifolder.htm
::
rem ----------------------------------------------------------------------
::
::	HELP:RUN IF OLDER - V1.1 - http://www.axel-hahn.de/
::	HELP:Execute a task only if it is older [n] days
::	HELP:If the execution was successful the time of last execution will
::	HELP:be stored in a textfile.
::
::	SYNTAX:SYNTAX:
::	SYNTAX:call run_if_older [n] [script/ program to execute] [label]
::	SYNTAX:  [n] age in days
::	SYNTAX:  [script/ program to execute]
::	SYNTAX:  [label] for saving and to identify the timestamp (optional)
::
rem ----------------------------------------------------------------------
::	2007-05-26   0.0   first lines
::	2007-06-10   1.0   first official version
::	2008-10-04   1.1   param /Y added at move command
rem ======================================================================

rem ----------------------------------------------------------------------
::	CONFIG
rem ----------------------------------------------------------------------
	set scriptdir=%~dp0
	set exeShowdate=%scriptdir%\showdate.exe
	set flagDate=%scriptdir%\lastrun.txt
	set tmpfile=%temp%\flagDate.tmp

	set AgeInDays=
	set sCommand=
	set sLabel=

	set currentDate=
	set minDate=
	set lastDate=

rem ----------------------------------------------------------------------
::	MAIN
rem ----------------------------------------------------------------------

	if "%1"=="/?" goto help
	if "%1"=="/h" goto help

	set AgeInDays=%1
	set sCommand=%2
	set sLabel=%3

	if "%AgeInDays%"=="" goto help
	if "%sCommand%"=="" goto showSyntax
	if "%sLabel%"=="" set sLabel=%sCommand%

rem ----------------------------------------------------------------------

	:: --- get current date
	for /F "tokens=*" %%a in ('%exeShowdate% /f:"yyyy-mm-dd hh:mm:ss"') do set currentDate=%%a

	:: --- get minimum date of last execution
	for /F "tokens=*" %%a in ('%exeShowdate% /f:"yyyy-mm-dd hh:mm:ss" /d:-%AgeInDays%') do set minDate=%%a

	:: --- get date of last execution
	for /F "tokens=1,2" %%a in ('type %flagDate% ^| findstr "^....-..-.." ^| findstr /c:"%sLabel%"') do set lastDate=%%a %%b

rem ----------------------------------------------------------------------

	echo.
	echo Task: %sLabel% 
	echo run every %AgeInDays% days
	echo.

	echo last execution: %lastDate%
	if "%lastDate%"=="" ( echo never executed ... && goto runNow )
	if "%lastDate%" LEQ "%minDate%" ( echo min age reached ... && goto runNow )
	echo need to wait...
	goto end
	
	
	:help
	echo.
	for /F "tokens=1* delims=:" %%a in ('findstr "^::.*HELP:" "%0"') do echo %%b

	:showSyntax
	echo.
	for /F "tokens=2* delims=:" %%a in ('findstr "^::.*SYNTAX:" "%0"') do echo.%%a
	echo.
	goto end
	
	:runNow
	echo START: %sCommand%
	%sCommand% && (
		echo OK: command was successful, write the flagfile with the date ...
		type %flagDate% | findstr /v /c:"%sLabel%" >%tmpfile%
		move /Y %tmpfile% %flagDate%
		echo %currentDate% %sLabel% >>%flagDate%
	)
	goto end
	
	
rem ----------------------------------------------------------------------
::	END
rem ----------------------------------------------------------------------
	:end
	echo.
	rem ping -n 3 localhost >nul
	
rem ----------------------------------------------------------------------
::  EOF
rem ----------------------------------------------------------------------
